const vec3 SPECULAR_LIGHT_COLOR = vec3(0.5, 0.5, 0.5);
const vec3 LIGHT_DIR = vec3(0.576, 0.576, 0.576);
const vec3 HALF_DIR = vec3(0.324, 0.324, 0.887);
const vec3 POINT_LIGHT_COLOR = vec3(1.0, 1.0, 0.9);
const float AMBIENT = 0.15f;
const float DIFFUSE = 0.5f;
const float SPECULAR = 5.15f;
const float ALPHA = 101.5;

varying mediump vec3 var_normal;
varying mediump vec2 var_texcoord0;
varying mediump vec4 var_position;
varying lowp vec4 var_color;

uniform lowp sampler2D tex0;
uniform lowp sampler2D tex1;
uniform lowp vec4 light_position_power; // xy position, w power

void main()
{
    // ambient + diffuse + light
    float n_dot_l = max(dot(var_normal, LIGHT_DIR), 0.0);
    vec4 color = texture2D(tex0, var_texcoord0.xy);
    vec3 d = vec3(light_position_power.xy - var_position.xy, 0.0);
    float iso_light = light_position_power.w / length(d);
    float illumination = min(DIFFUSE * n_dot_l + AMBIENT + iso_light, 1.0);
    float emissive = texture2D(tex1, var_texcoord0.xy).r;
    color.rgb = mix(color.rgb, POINT_LIGHT_COLOR, iso_light);
    vec3 c_ad = (emissive + (1.0 - emissive) * illumination) * color.rgb * var_color.a;

    // specular
    float n_dot_h = dot(var_normal, HALF_DIR);
    float s = SPECULAR * pow(n_dot_h, ALPHA);
    vec3 c_sp = (1.0 - emissive ) * min(s, 1.0) * SPECULAR_LIGHT_COLOR;

    // fragment color
    gl_FragColor = vec4(c_ad + c_sp + var_color.rgb, color.a);
}

